{% include "django/forms/widgets/text.html" %}
<br/>
<div id="{{ map_id }}"
     style="width: 100%; height: 300px;"
     class="map-googlemap">
    <noscript>
        <img src="https://maps.google.com/maps/api/staticmap?center={{ address }}&zoom={{ zoom }}&size=600x300&markers={{ address }}&key={{ gmaps_api_key }}">
    </noscript>
</div>
